[Libreoffice-commits] core.git: dbaccess/source sc/source sd/source ucb/source

Noel Grandin noel.grandin at collabora.co.uk
Tue Nov 22 12:38:13 UTC 2016


 dbaccess/source/ui/inc/JoinExchange.hxx                  |    1 
 dbaccess/source/ui/querydesign/JoinExchange.cxx          |    2 
 sc/source/filter/excel/xltools.cxx                       |   29 +++----
 sc/source/filter/inc/xltools.hxx                         |    9 --
 sd/source/ui/dlg/PhotoAlbumDialog.cxx                    |    3 
 sd/source/ui/dlg/PhotoAlbumDialog.hxx                    |    1 
 sd/source/ui/framework/factories/PresentationFactory.cxx |    6 -
 sd/source/ui/inc/framework/PresentationFactory.hxx       |    2 
 sd/source/ui/view/ToolBarManager.cxx                     |    8 -
 ucb/source/cacher/cachedcontentresultset.cxx             |   61 ++++++---------
 ucb/source/ucp/webdav-neon/UCBDeadPropertyValue.cxx      |   27 +++---
 ucb/source/ucp/webdav-neon/UCBDeadPropertyValue.hxx      |   15 ---
 12 files changed, 56 insertions(+), 108 deletions(-)

New commits:
commit e010834dc1a82fcb80dc23025001a752a0fb60a4
Author: Noel Grandin <noel.grandin at collabora.co.uk>
Date:   Tue Nov 22 12:41:43 2016 +0200

    remove some more global OUStrings
    
    Change-Id: Ic02754f98bfda3b7cd8c06857123d363a96e8d0e
    Reviewed-on: https://gerrit.libreoffice.org/31071
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Noel Grandin <noel.grandin at collabora.co.uk>

diff --git a/dbaccess/source/ui/inc/JoinExchange.hxx b/dbaccess/source/ui/inc/JoinExchange.hxx
index 450975c..8e16380 100644
--- a/dbaccess/source/ui/inc/JoinExchange.hxx
+++ b/dbaccess/source/ui/inc/JoinExchange.hxx
@@ -33,7 +33,6 @@ namespace dbaui
     typedef ::cppu::ImplHelper1< css::lang::XUnoTunnel > OJoinExchObj_Base;
     class OJoinExchObj : public TransferableHelper, public OJoinExchObj_Base
     {
-        static OUString         m_sJoinFormat;
         bool                m_bFirstEntry;
 
     protected:
diff --git a/dbaccess/source/ui/querydesign/JoinExchange.cxx b/dbaccess/source/ui/querydesign/JoinExchange.cxx
index c4c0dcf..bca06ae 100644
--- a/dbaccess/source/ui/querydesign/JoinExchange.cxx
+++ b/dbaccess/source/ui/querydesign/JoinExchange.cxx
@@ -28,8 +28,6 @@ namespace dbaui
     using namespace ::com::sun::star::lang;
     using namespace ::com::sun::star::datatransfer;
 
-    OUString OJoinExchObj::m_sJoinFormat;
-
     // class OJoinExchObj
     OJoinExchObj::OJoinExchObj(const OJoinExchangeData& jxdSource,bool _bFirstEntry)
         :m_bFirstEntry(_bFirstEntry)
diff --git a/sc/source/filter/excel/xltools.cxx b/sc/source/filter/excel/xltools.cxx
index 1392eb5..f2e33cf 100644
--- a/sc/source/filter/excel/xltools.cxx
+++ b/sc/source/filter/excel/xltools.cxx
@@ -434,9 +434,8 @@ OUString XclTools::GetXclFontName( const OUString& rFontName )
 }
 
 // built-in defined names
-const OUString XclTools::maDefNamePrefix( "Excel_BuiltIn_" );
-
-const OUString XclTools::maDefNamePrefixXml ( "_xlnm." );
+static const char maDefNamePrefix[]    = "Excel_BuiltIn_"; /// Prefix for built-in defined names.
+static const char maDefNamePrefixXml[] = "_xlnm.";         /// Prefix for built-in defined names for OOX
 
 static const sal_Char* const ppcDefNames[] =
 {
@@ -483,7 +482,7 @@ OUString XclTools::GetBuiltInDefNameXml( sal_Unicode cBuiltIn )
 
 sal_Unicode XclTools::GetBuiltInDefNameIndex( const OUString& rDefName )
 {
-    sal_Int32 nPrefixLen = maDefNamePrefix.getLength();
+    sal_Int32 nPrefixLen = strlen(maDefNamePrefix);
     if( rDefName.startsWithIgnoreAsciiCase( maDefNamePrefix ) )
     {
         for( sal_Unicode cBuiltIn = 0; cBuiltIn < EXC_BUILTIN_UNKNOWN; ++cBuiltIn )
@@ -505,8 +504,8 @@ sal_Unicode XclTools::GetBuiltInDefNameIndex( const OUString& rDefName )
 
 // built-in style names
 
-const OUString XclTools::maStyleNamePrefix1( "Excel_BuiltIn_" );
-const OUString XclTools::maStyleNamePrefix2( "Excel Built-in " );
+static const char maStyleNamePrefix1[] = "Excel_BuiltIn_";  /// Prefix for built-in cell style names.
+static const char maStyleNamePrefix2[] = "Excel Built-in "; /// Prefix for built-in cell style names from OOX filter.
 
 static const sal_Char* const ppcStyleNames[] =
 {
@@ -565,9 +564,9 @@ bool XclTools::IsBuiltInStyleName( const OUString& rStyleName, sal_uInt8* pnStyl
 
     sal_Int32 nPrefixLen = 0;
     if( rStyleName.startsWithIgnoreAsciiCase( maStyleNamePrefix1 ) )
-        nPrefixLen = maStyleNamePrefix1.getLength();
+        nPrefixLen = strlen(maStyleNamePrefix1);
     else if( rStyleName.startsWithIgnoreAsciiCase( maStyleNamePrefix2 ) )
-        nPrefixLen = maStyleNamePrefix2.getLength();
+        nPrefixLen = strlen(maStyleNamePrefix2);
     if( nPrefixLen > 0 )
     {
         for( sal_uInt8 nId = 0; nId < SAL_N_ELEMENTS( ppcStyleNames ); ++nId )
@@ -629,8 +628,8 @@ bool XclTools::GetBuiltInStyleId( sal_uInt8& rnStyleId, sal_uInt8& rnLevel, cons
 
 // conditional formatting style names
 
-const OUString XclTools::maCFStyleNamePrefix1( "Excel_CondFormat_" );
-const OUString XclTools::maCFStyleNamePrefix2( "ConditionalStyle_" );
+static const char maCFStyleNamePrefix1[] = "Excel_CondFormat_"; /// Prefix for cond. formatting style names.
+static const char maCFStyleNamePrefix2[] = "ConditionalStyle_"; /// Prefix for cond. formatting style names from OOX filter.
 
 OUString XclTools::GetCondFormatStyleName( SCTAB nScTab, sal_Int32 nFormat, sal_uInt16 nCondition )
 {
@@ -670,8 +669,8 @@ void XclTools::SkipSubStream( XclImpStream& rStrm )
 
 // Basic macro names
 
-const OUString XclTools::maSbMacroPrefix( "vnd.sun.star.script:" );
-const OUString XclTools::maSbMacroSuffix( "?language=Basic&location=document" );
+static const char maSbMacroPrefix[] = "vnd.sun.star.script:";              /// Prefix for StarBasic macros.
+static const char maSbMacroSuffix[] = "?language=Basic&location=document"; /// Suffix for StarBasic macros.
 
 OUString XclTools::GetSbMacroUrl( const OUString& rMacroName, SfxObjectShell* pDocShell )
 {
@@ -685,12 +684,12 @@ OUString XclTools::GetSbMacroUrl( const OUString& rMacroName, SfxObjectShell* pD
 OUString XclTools::GetXclMacroName( const OUString& rSbMacroUrl )
 {
     sal_Int32 nSbMacroUrlLen = rSbMacroUrl.getLength();
-    sal_Int32 nMacroNameLen = nSbMacroUrlLen - maSbMacroPrefix.getLength() - maSbMacroSuffix.getLength();
+    sal_Int32 nMacroNameLen = nSbMacroUrlLen - strlen(maSbMacroPrefix) - strlen(maSbMacroSuffix);
     if( (nMacroNameLen > 0) && rSbMacroUrl.startsWithIgnoreAsciiCase( maSbMacroPrefix ) &&
             rSbMacroUrl.endsWithIgnoreAsciiCase( maSbMacroSuffix ) )
     {
-        sal_Int32 nPrjDot = rSbMacroUrl.indexOf( '.', maSbMacroPrefix.getLength() ) + 1;
-        return rSbMacroUrl.copy( nPrjDot, nSbMacroUrlLen - nPrjDot - maSbMacroSuffix.getLength() );
+        sal_Int32 nPrjDot = rSbMacroUrl.indexOf( '.', strlen(maSbMacroPrefix) ) + 1;
+        return rSbMacroUrl.copy( nPrjDot, nSbMacroUrlLen - nPrjDot - strlen(maSbMacroSuffix) );
     }
     return OUString();
 }
diff --git a/sc/source/filter/inc/xltools.hxx b/sc/source/filter/inc/xltools.hxx
index 7ca6e29..2a202c3 100644
--- a/sc/source/filter/inc/xltools.hxx
+++ b/sc/source/filter/inc/xltools.hxx
@@ -239,15 +239,6 @@ public:
     /** Returns the Excel macro name from a full StarBasic macro URL. */
     static OUString GetXclMacroName( const OUString& rSbMacroUrl );
 
-private:
-    static const OUString maDefNamePrefix;      /// Prefix for built-in defined names.
-    static const OUString maDefNamePrefixXml;   /// Prefix for built-in defined names for OOX
-    static const OUString maStyleNamePrefix1;   /// Prefix for built-in cell style names.
-    static const OUString maStyleNamePrefix2;   /// Prefix for built-in cell style names from OOX filter.
-    static const OUString maCFStyleNamePrefix1; /// Prefix for cond. formatting style names.
-    static const OUString maCFStyleNamePrefix2; /// Prefix for cond. formatting style names from OOX filter.
-    static const OUString maSbMacroPrefix;   /// Prefix for StarBasic macros.
-    static const OUString maSbMacroSuffix;   /// Suffix for StarBasic macros.
 };
 
 // read/write colors ----------------------------------------------------------
diff --git a/sd/source/ui/dlg/PhotoAlbumDialog.cxx b/sd/source/ui/dlg/PhotoAlbumDialog.cxx
index 5456683..54c6be1 100644
--- a/sd/source/ui/dlg/PhotoAlbumDialog.cxx
+++ b/sd/source/ui/dlg/PhotoAlbumDialog.cxx
@@ -36,8 +36,6 @@
 namespace sd
 {
 
-OUString SdPhotoAlbumDialog::sDirUrl;
-
 SdPhotoAlbumDialog::SdPhotoAlbumDialog(vcl::Window* pWindow, SdDrawDocument* pActDoc)
 : ModalDialog(pWindow, "PhotoAlbumCreatorDialog", "modules/simpress/ui/photoalbum.ui"),
   pDoc(pActDoc)
@@ -73,7 +71,6 @@ SdPhotoAlbumDialog::SdPhotoAlbumDialog(vcl::Window* pWindow, SdDrawDocument* pAc
     pInsTypeCombo->SetSelectHdl(LINK(this, SdPhotoAlbumDialog, TypeSelectHdl));
 
     mpGraphicFilter = new GraphicFilter;
-    sDirUrl.clear();
     pAddBtn->GrabFocus();
     pImagesLst->Clear();
 }
diff --git a/sd/source/ui/dlg/PhotoAlbumDialog.hxx b/sd/source/ui/dlg/PhotoAlbumDialog.hxx
index 122380c0..e6541b5 100644
--- a/sd/source/ui/dlg/PhotoAlbumDialog.hxx
+++ b/sd/source/ui/dlg/PhotoAlbumDialog.hxx
@@ -49,7 +49,6 @@ public:
     virtual void dispose() override;
 
 private:
-    static OUString sDirUrl;
     VclPtr<CancelButton>   pCancelBtn;
     VclPtr<PushButton>     pCreateBtn;
 
diff --git a/sd/source/ui/framework/factories/PresentationFactory.cxx b/sd/source/ui/framework/factories/PresentationFactory.cxx
index 76444d8..7a46a15 100644
--- a/sd/source/ui/framework/factories/PresentationFactory.cxx
+++ b/sd/source/ui/framework/factories/PresentationFactory.cxx
@@ -88,7 +88,7 @@ private:
 
 //===== PresentationFactory ===================================================
 
-const OUString PresentationFactory::msPresentationViewURL("private:resource/view/Presentation");
+static const char gsPresentationViewURL[] = "private:resource/view/Presentation";
 
 PresentationFactory::PresentationFactory (
     const Reference<frame::XController>& rxController)
@@ -125,7 +125,7 @@ Reference<XResource> SAL_CALL PresentationFactory::createResource (
     ThrowIfDisposed();
 
     if (rxViewId.is())
-        if ( ! rxViewId->hasAnchor() && rxViewId->getResourceURL().equals(msPresentationViewURL))
+        if ( ! rxViewId->hasAnchor() && rxViewId->getResourceURL() == gsPresentationViewURL)
             return new PresentationView(rxViewId);
 
     return Reference<XResource>();
@@ -215,7 +215,7 @@ void SAL_CALL PresentationFactoryProvider::initialize(
             Reference<XConfigurationController> xCC (xCM->getConfigurationController());
             if (xCC.is())
                 xCC->addResourceFactory(
-                    PresentationFactory::msPresentationViewURL,
+                    gsPresentationViewURL,
                     new PresentationFactory(xController));
         }
         catch (RuntimeException&)
diff --git a/sd/source/ui/inc/framework/PresentationFactory.hxx b/sd/source/ui/inc/framework/PresentationFactory.hxx
index 1b17080..32675d1 100644
--- a/sd/source/ui/inc/framework/PresentationFactory.hxx
+++ b/sd/source/ui/inc/framework/PresentationFactory.hxx
@@ -53,8 +53,6 @@ class PresentationFactory
       public PresentationFactoryInterfaceBase
 {
 public:
-    static const OUString msPresentationViewURL;
-
     PresentationFactory (
         const css::uno::Reference<css::frame::XController>& rxController);
     virtual ~PresentationFactory() override;
diff --git a/sd/source/ui/view/ToolBarManager.cxx b/sd/source/ui/view/ToolBarManager.cxx
index eb40f3c..971f408 100644
--- a/sd/source/ui/view/ToolBarManager.cxx
+++ b/sd/source/ui/view/ToolBarManager.cxx
@@ -296,8 +296,6 @@ public:
     ToolBarRules& GetToolBarRules() { return maToolBarRules;}
 
 private:
-    const static OUString msToolBarResourcePrefix;
-
     mutable ::osl::Mutex maMutex;
     ViewShellBase& mrBase;
     std::shared_ptr<sd::tools::EventMultiplexer> mpEventMultiplexer;
@@ -511,8 +509,6 @@ void ToolBarManager::ToolBarsDestroyed()
 
 //===== ToolBarManager::Implementation =======================================
 
-const OUString ToolBarManager::Implementation::msToolBarResourcePrefix("private:resource/toolbar/");
-
 ToolBarManager::Implementation::Implementation (
     ViewShellBase& rBase,
     const std::shared_ptr<sd::tools::EventMultiplexer>& rpMultiplexer,
@@ -894,9 +890,7 @@ IMPL_LINK_NOARG(ToolBarManager::Implementation, SetValidCallback, void*, void)
 OUString ToolBarManager::Implementation::GetToolBarResourceName (
     const OUString& rsBaseName)
 {
-    OUString sToolBarName (msToolBarResourcePrefix);
-    sToolBarName += rsBaseName;
-    return sToolBarName;
+    return "private:resource/toolbar/" + rsBaseName;
 }
 
 bool ToolBarManager::Implementation::CheckPlugInMode (const OUString& rsName) const
diff --git a/ucb/source/ucp/webdav-neon/UCBDeadPropertyValue.cxx b/ucb/source/ucp/webdav-neon/UCBDeadPropertyValue.cxx
index f312d50..a1a2c7a 100644
--- a/ucb/source/ucp/webdav-neon/UCBDeadPropertyValue.cxx
+++ b/ucb/source/ucp/webdav-neon/UCBDeadPropertyValue.cxx
@@ -46,21 +46,20 @@ struct UCBDeadPropertyValueParseContext
     ~UCBDeadPropertyValueParseContext() { delete pType; delete pValue; }
 };
 
-// static
-const OUString UCBDeadPropertyValue::aTypeString("string");
-const OUString UCBDeadPropertyValue::aTypeLong("long");
-const OUString UCBDeadPropertyValue::aTypeShort("short");
-const OUString UCBDeadPropertyValue::aTypeBoolean("boolean");
-const OUString UCBDeadPropertyValue::aTypeChar("char");
-const OUString UCBDeadPropertyValue::aTypeByte("byte");
-const OUString UCBDeadPropertyValue::aTypeHyper("hyper");
-const OUString UCBDeadPropertyValue::aTypeFloat("float");
-const OUString UCBDeadPropertyValue::aTypeDouble("double");
+static const char aTypeString[] = "string";
+static const char aTypeLong[] = "long";
+static const char aTypeShort[] = "short";
+static const char aTypeBoolean[] = "boolean";
+static const char aTypeChar[] = "char";
+static const char aTypeByte[] = "byte";
+static const char aTypeHyper[] = "hyper";
+static const char aTypeFloat[] = "float";
+static const char aTypeDouble[] = "double";
+
+static const char aXMLPre[] = "<ucbprop><type>";
+static const char aXMLMid[] = "</type><value>";
+static const char aXMLEnd[] = "</value></ucbprop>";
 
-// static
-const OUString UCBDeadPropertyValue::aXMLPre("<ucbprop><type>");
-const OUString UCBDeadPropertyValue::aXMLMid("</type><value>");
-const OUString UCBDeadPropertyValue::aXMLEnd("</value></ucbprop>");
 
 #define STATE_TOP (1)
 
diff --git a/ucb/source/ucp/webdav-neon/UCBDeadPropertyValue.hxx b/ucb/source/ucp/webdav-neon/UCBDeadPropertyValue.hxx
index f0c93be..b93c142 100644
--- a/ucb/source/ucp/webdav-neon/UCBDeadPropertyValue.hxx
+++ b/ucb/source/ucp/webdav-neon/UCBDeadPropertyValue.hxx
@@ -37,21 +37,6 @@ namespace webdav_ucp
 
 class UCBDeadPropertyValue
 {
-private:
-    static const OUString aTypeString;
-    static const OUString aTypeLong;
-    static const OUString aTypeShort;
-    static const OUString aTypeBoolean;
-    static const OUString aTypeChar;
-    static const OUString aTypeByte;
-    static const OUString aTypeHyper;
-    static const OUString aTypeFloat;
-    static const OUString aTypeDouble;
-
-    static const OUString aXMLPre;
-    static const OUString aXMLMid;
-    static const OUString aXMLEnd;
-
 public:
     static bool supportsType( const css::uno::Type & rType );
 


More information about the Libreoffice-commits mailing list
diff --git a/ucb/source/cacher/cachedcontentresultset.cxx b/ucb/source/cacher/cachedcontentresultset.cxx
index 6b0a8fc..44e9aa7 100644
--- a/ucb/source/cacher/cachedcontentresultset.cxx
+++ b/ucb/source/cacher/cachedcontentresultset.cxx
@@ -376,12 +376,6 @@ class CCRS_PropertySetInfo :
     Sequence< css::beans::Property >*
                             m_pProperties;
 
-    //some helping variables ( names for my special properties )
-    static OUString m_aPropertyNameForCount;
-    static OUString m_aPropertyNameForFinalCount;
-    static OUString m_aPropertyNameForFetchSize;
-    static OUString m_aPropertyNameForFetchDirection;
-
     long                    m_nFetchSizePropertyHandle;
     long                    m_nFetchDirectionPropertyHandle;
 
@@ -433,10 +427,11 @@ public:
         throw( RuntimeException, std::exception ) override;
 };
 
-OUString    CCRS_PropertySetInfo::m_aPropertyNameForCount( "RowCount" );
-OUString    CCRS_PropertySetInfo::m_aPropertyNameForFinalCount( "IsRowCountFinal" );
-OUString    CCRS_PropertySetInfo::m_aPropertyNameForFetchSize( "FetchSize" );
-OUString    CCRS_PropertySetInfo::m_aPropertyNameForFetchDirection( "FetchDirection" );
+//some helping variables ( names for my special properties )
+static const char g_sPropertyNameForCount[] = "RowCount";
+static const char g_sPropertyNameForFinalCount[] = "IsRowCountFinal";
+static const char g_sPropertyNameForFetchSize[] = "FetchSize";
+static const char g_sPropertyNameForFetchDirection[] = "FetchDirection";
 
 CCRS_PropertySetInfo::CCRS_PropertySetInfo(
         Reference< XPropertySetInfo > const & xInfo )
@@ -447,8 +442,8 @@ CCRS_PropertySetInfo::CCRS_PropertySetInfo(
     //initialize list of properties:
 
     // it is required, that the received xInfo contains the two
     // properties with names 'm_aPropertyNameForCount' and
     // 'm_aPropertyNameForFinalCount'
 
     if( xInfo.is() )
     {
@@ -462,8 +457,8 @@ CCRS_PropertySetInfo::CCRS_PropertySetInfo(
     }
 
     //ensure, that we haven't got the Properties 'FetchSize' and 'Direction' twice:
-    sal_Int32 nFetchSize = impl_getPos( m_aPropertyNameForFetchSize );
-    sal_Int32 nFetchDirection = impl_getPos( m_aPropertyNameForFetchDirection );
+    sal_Int32 nFetchSize = impl_getPos( g_sPropertyNameForFetchSize );
+    sal_Int32 nFetchDirection = impl_getPos( g_sPropertyNameForFetchDirection );
     sal_Int32 nDeleted = 0;
     if( nFetchSize != -1 )
         nDeleted++;
@@ -483,7 +478,7 @@ CCRS_PropertySetInfo::CCRS_PropertySetInfo(
     }
     {
         Property& rMyProp = (*m_pProperties)[ nOrigProps - nDeleted ];
-        rMyProp.Name = m_aPropertyNameForFetchSize;
+        rMyProp.Name = g_sPropertyNameForFetchSize;
         rMyProp.Type = cppu::UnoType<sal_Int32>::get();
         rMyProp.Attributes = PropertyAttribute::BOUND | PropertyAttribute::MAYBEDEFAULT;
 
@@ -497,7 +492,7 @@ CCRS_PropertySetInfo::CCRS_PropertySetInfo(
     }
     {
         Property& rMyProp = (*m_pProperties)[ nOrigProps - nDeleted + 1 ];
-        rMyProp.Name = m_aPropertyNameForFetchDirection;
+        rMyProp.Name = g_sPropertyNameForFetchDirection;
         rMyProp.Type = cppu::UnoType<sal_Bool>::get();
         rMyProp.Attributes = PropertyAttribute::BOUND | PropertyAttribute::MAYBEDEFAULT;
 
@@ -619,10 +614,10 @@ bool SAL_CALL CCRS_PropertySetInfo
 bool SAL_CALL CCRS_PropertySetInfo
         ::impl_isMyPropertyName( const OUString& rPropertyName )
 {
-    return ( rPropertyName == m_aPropertyNameForCount
-    || rPropertyName == m_aPropertyNameForFinalCount
-    || rPropertyName == m_aPropertyNameForFetchSize
-    || rPropertyName == m_aPropertyNameForFetchDirection );
+    return ( rPropertyName == g_sPropertyNameForCount
+    || rPropertyName == g_sPropertyNameForFinalCount
+    || rPropertyName == g_sPropertyNameForFetchSize
+    || rPropertyName == g_sPropertyNameForFetchDirection );
 }
 
 sal_Int32 SAL_CALL CCRS_PropertySetInfo
@@ -1027,8 +1022,7 @@ void SAL_CALL CachedContentResultSet
         //'RowCount' and 'IsRowCountFinal' are readonly!
         throw IllegalArgumentException();
     }
-    if( aProp.Name == CCRS_PropertySetInfo
-                        ::m_aPropertyNameForFetchDirection )
+    if( aProp.Name == g_sPropertyNameForFetchDirection )
     {
         //check value
         sal_Int32 nNew;
@@ -1065,8 +1059,7 @@ void SAL_CALL CachedContentResultSet
         //send PropertyChangeEvent to listeners
         impl_notifyPropertyChangeListeners( aEvt );
     }
-    else if( aProp.Name == CCRS_PropertySetInfo
-                        ::m_aPropertyNameForFetchSize )
+    else if( aProp.Name == g_sPropertyNameForFetchSize )
     {
         //check value
         sal_Int32 nNew;
@@ -1133,22 +1126,22 @@ Any SAL_CALL CachedContentResultSet
         //throws UnknownPropertyException, if so
 
     Any aValue;
-    if( rPropertyName == CCRS_PropertySetInfo::m_aPropertyNameForCount )
+    if( rPropertyName == g_sPropertyNameForCount )
     {
         osl::Guard< osl::Mutex > aGuard( m_aMutex );
         aValue <<= m_nKnownCount;
     }
-    else if( rPropertyName == CCRS_PropertySetInfo::m_aPropertyNameForFinalCount )
+    else if( rPropertyName == g_sPropertyNameForFinalCount )
     {
         osl::Guard< osl::Mutex > aGuard( m_aMutex );
         aValue <<= m_bFinalCount;
     }
-    else if( rPropertyName == CCRS_PropertySetInfo::m_aPropertyNameForFetchSize )
+    else if( rPropertyName == g_sPropertyNameForFetchSize )
     {
         osl::Guard< osl::Mutex > aGuard( m_aMutex );
         aValue <<= m_nFetchSize;
     }
-    else if( rPropertyName == CCRS_PropertySetInfo::m_aPropertyNameForFetchDirection )
+    else if( rPropertyName == g_sPropertyNameForFetchDirection )
     {
         osl::Guard< osl::Mutex > aGuard( m_aMutex );
         aValue <<= m_nFetchDirection;
@@ -1204,15 +1197,12 @@ void SAL_CALL CachedContentResultSet
             ::impl_isMyPropertyName( rEvt.PropertyName ) )
     {
         //don't notify foreign events on fetchsize and fetchdirection
-        if( aEvt.PropertyName == CCRS_PropertySetInfo
-                                ::m_aPropertyNameForFetchSize
-        || aEvt.PropertyName == CCRS_PropertySetInfo
-                                ::m_aPropertyNameForFetchDirection )
+        if( aEvt.PropertyName == g_sPropertyNameForFetchSize
+        || aEvt.PropertyName == g_sPropertyNameForFetchDirection )
             return;
 
         //adjust my props 'RowCount' and 'IsRowCountFinal'
-        if( aEvt.PropertyName == CCRS_PropertySetInfo
-                            ::m_aPropertyNameForCount )
+        if( aEvt.PropertyName == g_sPropertyNameForCount )
         {//RowCount changed
 
             //check value
@@ -1225,8 +1215,7 @@ void SAL_CALL CachedContentResultSet
 
             impl_changeRowCount( m_nKnownCount, nNew );
         }
-        else if( aEvt.PropertyName == CCRS_PropertySetInfo
-                                ::m_aPropertyNameForFinalCount )
+        else if( aEvt.PropertyName == g_sPropertyNameForFinalCount )
         {//IsRowCountFinal changed
 
             //check value
@@ -447,8 +442,8 @@ CCRS_PropertySetInfo::CCRS_PropertySetInfo(
 
     // it is required, that the received xInfo contains the two
-    // properties with names 'm_aPropertyNameForCount' and
-    // 'm_aPropertyNameForFinalCount'
+    // properties with names 'g_sPropertyNameForCount' and
+    // 'g_sPropertyNameForFinalCount'
 
     if( xInfo.is() )